Wrapper for SteamNews from the SteamWebAPI

# Description
    
This packages validates the input of either (or both) a steam appid or the name of the game and outputs a dict with the query result

This package is still a work in progess and'll be updated in regular intervals.

# Installation
 
## Normal installation

```bash
pip install steamnews
```

## Development installation

```bash
git clone https://github.com/Kamigiri/steamnews
cd steamnews
pip install --editable 
```